@@ -17,7 +17,7 @@ from threading import Thread, Lock
 from queue import Queue
 
 # System
-import logging, time, os
+import logging, time, os, subprocess
 
 # Open Computer Vision
 import cv2
@@ -266,12 +266,10 @@ class nanoCapture(Thread):
             #        'bufapi-version=false '
             ###################################################################################
 
-            if framerate == 120:
-                capture_width = 1280
-                capture_height = 720
-                sensormode = 5
-            else:
-                sensormode = -1
+            # if framerate > 60:
+            #     sensormode = 5
+            # else:
+            #     sensormode = -1
 
             if exposure_time <= 0:
                 # auto exposure
@@ -281,7 +279,7 @@ class nanoCapture(Thread):
                     'sensor-id={:d} '.format(camera_num)            +
                     'name="NanoCam{:d}" '.format(camera_num)        +
                     'do-timestamp=true '                            +
-                    'sensor-mode={:d} '.format(sensormode)          +
+                    # 'sensor-mode={:d} '.format(sensormode)          +
                     'timeout=0 '                                    +
                     'blocksize=-1 '                                 +
                     'num-buffers=-1 '                               +
@@ -310,7 +308,7 @@ class nanoCapture(Thread):
                     'timeout=0 '                                    +
                     'blocksize=-1 '                                 +
                     'num-buffers=-1 '                               +
-                    'sensor-mode={:d} '.format(sensormode)          +
+                    # 'sensor-mode={:d} '.format(sensormode)          +
                     'tnr-strength=-1 '                              +
                     'tnr-mode=1 '                                   +
                     'aeantibanding=1 '                              +
@@ -413,18 +411,21 @@ class nanoCapture(Thread):
     @property
     def exposure(self):              
         if self.cam_open:
-            return self.capture._exposure  
+            # return os.system("v4l2-ctl -C exposure_absolute -d {}".format(self._camera_num))
+            res = subprocess.run(["v4l2-ctl", "-C exposure_absolute -d {}".format(self._camera_num)], stdout=subprocess.PIPE).stdout.decode('utf-8')
+            return res
         else: return float("NaN")
     @exposure.setter
     def exposure(self, val):
         if val is None:
             return
         val = int(val)
-        self._exposure = val
         if self.cam_open:
             with self.cam_lock:
-                os.system("v4l2-ctl -c exposure_absolute={} -d {}".format(val, self._camera_num))
-            if not self.log.full(): self.log.put_nowait((logging.INFO, "NanoCap:Exposure:{}".format(self._exposure)))
+                res = subprocess.run(["v4l2-ctl -c exposure_absolute={} -d {}".format(val, self._camera_num)], stdout=subprocess.PIPE).stdout.decode('utf-8')
+                # os.system("v4l2-ctl -c exposure_absolute={} -d {}".format(val, self._camera_num))
+                self._exposure = val
+            if not self.log.full(): self.log.put_nowait((logging.INFO, "NanoCap:Exposure:{}".format(val)))
         else:
             if not self.log.full(): self.log.put_nowait((logging.ERROR, "NanoCap:Failed to set exposure to{}!".format(val)))
 
